# renkon

[![PyPI - Version](https://img.shields.io/pypi/v/renkon.svg)](https://pypi.org/project/renkon)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/renkon.svg)](https://pypi.org/project/renkon)
[![Tests](https://github.com/DylanLukes/renkon/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/DylanLukes/renkon/actions/workflows/test.yml)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install renkon
```

## License

`renkon` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
